# TriggerDateName

Name of the trigger date of the order action. 

## Enum

* `CONTRACTEFFECTIVE` (value: `'ContractEffective'`)

* `SERVICEACTIVATION` (value: `'ServiceActivation'`)

* `CUSTOMERACCEPTANCE` (value: `'CustomerAcceptance'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


